/* Soma - Copyright (C) 2003 Bakunin - Andrea Marchesini
 *                                     <bakunin@autistici.org>
 *
 * This source code is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Public License as published 
 * by the Free Software Foundation; either version 2 of the License,
 * or (at your option) any later version.
 *
 * This source code is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
 * Please refer to the GNU Public License for more details.
 *
 * You should have received a copy of the GNU Public License along with
 * this source code; if not, write to:
 * Free Software Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 */

#include <code.h>
#include <commons.h>

/* Lista per PathSong e PathSpot di ogni file audio della playlist.
 * Questa lista semplice va poi legata dentro a soma_data per la gestione
 * della PathSong e della PathSpot. */
typedef struct _song_
{
  char *name;

  /* E' gia' stata suonata? Verra' messo a 1 quando il brano viene suonato e 
   * mezzo a 0 quando non si e' + trovato brani a 0, quindi tutti sono gia'
   * stati suonati e riinizia il giro */
  int play;

  /* Se questo e' messo a 1 vuol dire che appartiene all'elenco file audio
   * del palinsesto attualmente in onda. Servira' poi, al cambio del palinsesto
   * per essere eliminato */
  int pl;

  /* Se web e' pari a PLAY_FILES vuol dire che e' un file presente sul PC e 
   * quindi devo lanciare ProgramSong, viceversa devo usare ProgramStream, 
   * perche' si tratta di un file messo in qualche ftp o http. */
  int web;

  struct _song_ *next;
}
song;

/* Gestione directory contenenti file audio. Altra lista semplice semplice.
 * Viene legato a soma_data (per l'elenco trovato nel file di config) o
 * in soma_pl (per quelle proprie di un palinsesto). */
typedef struct _soma_dir_
{
  char *dir;
  struct _soma_dir_ *next;
}
soma_dir;

/* Lista del palinsesto.
 * Questa lista e' doppia concatenata circolare. Doppia concatenata perche'
 * diventa poi utile fare controlli, circolare perche' soma deve funzionare
 * per giorni e giorni, quindi il palinsesto deve andare in loop. */
typedef struct _soma_pl_
{
  /* Descrizione del palinsesto. */
  char *Description;

  /* Questi 2 valori sono codificati come HHMM. */
  int Start;
  int Stop;

  /* Vedere code.h per i type. */
  int Type;

  /* Sezione dedicata ai FILES */
  int Random;
  int SoftStop;

  /* RapportoSong */
  int RatioSong;

  /* RapportoSpot */
  int RatioSpot;

  /* Elenco di directory proprie di questo palinsesto. */
  soma_dir *PathSong;
  soma_dir *PathSpot;

  /* Sezione dedicata allo STREAM */
  char *Stream;

  /* Il jingle iniziale */
  char *Jingle;

  /* Il modulo opzionale per questo palinsesto */
  char *Module;

  struct _soma_pl_ *next;
  struct _soma_pl_ *prev;

}
soma_pl;

/* Lista per le opzioni da dare al comando di ProgramSongs o ProgramStream. 
 * Utile per la ricreazione dell'array degli argomenti quando devo fare una
 * execve. */
typedef struct _soma_opt_
{
  char *opt;
  struct _soma_opt_ *next;
}
soma_opt;

/* Configurazione generale di Soma. Questa struttura, ovviamente e' quella
 * che in tutto soma si chiama conf. */
typedef struct
{
  /* File di configurazione */
  char *FileCfg;

  /* Valore di debug e lo status attuale */
  int Debug;
  char *LogFile;

  char Status[SOMA_MAX_BUFF];

  /* Variabili di funzionamento */
  int Background;
  char *User;
  char *Password;

  /* Elenco directory trovate nel file di config */
  soma_dir *PathSong;
  soma_dir *PathSpot;

  /* Numero di song e spot presenti nel DB. Questo e' utile per la macro
   * getrandom. Questa macro mi da un valore random da min a max ove min e'
   * 0 e max e' n_song o n_spot. La uso quando devo prendere un pezzo random
   * nell'elenco dei brani */
  int n_song;
  int n_spot;

  /* Collegamento alle strutture dati song e spot */
  song *song;
  song *spot;

  /* Programmi, opzioni e numero di opzioni */
  char *ProgramSong;
  soma_opt *OptionsSong;

  int n_OptionsSong;

  char *ProgramStream;
  soma_opt *OptionsStream;

  int n_OptionsStream;

  /* File di palinsesto: Letto dal file di config oppure cambiato grazie a 
   * somaclient. */
  char *Palinsesto_fl;

  /* Collegamento alla struttura dati del palinsesto */
  soma_pl *Palinsesto;

  /* SOCKET: */
  char *ServerName;
  int Port;
  int Listen;

  /* MODULI */
  char *PathModules;

  /* NEXT_SONG */
  char *next_song;
}
soma_data;

/* EOF */
